
###################
test_samples.option
###################

.. module:: test_samples.option


.. data:: TEST_OPTION


   .. note:: 

      
                  This variable is a user-editable option,
                  meaning it appears within the cache and can be
                  edited on the command line by the :code:`-D` flag.
                  

   This is a documentation of an option.
   

   :Help text: "This is a user-accessible option"

   :Default value: OFF

   :type: bool

